==> owncloud-client_1.8.1+dfsg.orig.tar.xz: owncloudclient-1.8.1/CONTRIBUTING.md <==
## Submitting Desktop Client issues

If you have questions about how to use the ownCloud Desktop Client, please
direct these to the [mailing list][mailinglist] or our [forum][forum].
We are also available on [IRC][irc].

### Bug Reporting Guidelines
* __Important__: Report the issue using our [template][template], it includes all the
  informations we need to track down the issue.  
* This repository is *only* for issues within the ownCloud desktop client. 
  Issues in other compontents should be reported in their own repositores: 
  - [ownCloud server](https://github.com/owncloud/core/issues)
  - [ownCloud apps](https://github.com/owncloud/apps/issues) (e.g. Calendar,
    Contacts...)
  - [Android client](https://github.com/owncloud/android/issues)
  - [iOS client](https://github.com/owncloud/ios-issues/issues)
* Search the existing issues first, it's likely that your issue was already
  reported.

If your issue appears to be a bug, and hasn't been reported, open a new issue.

Help us to maximize the effort we can spend fixing issues and adding new
features, by not reporting duplicate issues.

[template]: https://raw.github.com/owncloud/client/master/issue_template.md
[mailinglist]: https://mail.kde.org/mailman/listinfo/owncloud
[forum]: http://forum.owncloud.org/
[irc]: http://webchat.freenode.net/?channels=owncloud&uio=d4

## Contributing to Source Code

Thanks for wanting to contribute source code to ownCloud. That's great!

Before we're able to merge your code to ownCloud Desktop Client, you need to sign
our [Contributor Agreement][agreement].

Please read the [Desktop Client Manual][desktopman] and the [Developer
Manuals][devmanual] to get useful infos like how to create your first
application or how to test the ownCloud code with phpunit.

[agreement]: http://owncloud.org/about/contributor-agreement/
[devmanual]: http://owncloud.org/dev
[desktopman]: http://doc.owncloud.org/desktop

## Translations
Please submit translations via [Transifex][transifex].

[transifex]: https://www.transifex.com/projects/p/owncloud/

==> owncloud-client_2.6.3.14058+dfsg.orig.tar.xz: owncloudclient-2.6.3.14058/CONTRIBUTING.md <==
## Submitting Desktop Client issues

If you have questions about how to use the ownCloud Desktop Client, please
direct these to the [mailing list][mailinglist] or our [forum][forum].
We are also available on [IRC][irc].

### Bug Reporting Guidelines
* __Important__: Report the issue using our [template][template], it includes all the
  information we need to track down the issue.  
* __SECURITY__: Report any potential security bug to security@owncloud.com following our [security policy](https://owncloud.org/security/) instead of filing an issue in our bug tracker
* This repository is *only* for issues within the ownCloud desktop client. 
  Issues in other components should be reported in their own repositores: 
  - [ownCloud server](https://github.com/owncloud/core/issues)
  - [ownCloud apps](https://github.com/owncloud/apps/issues) (e.g. Calendar,
    Contacts...)
  - [Android client](https://github.com/owncloud/android/issues)
  - [iOS client](https://github.com/owncloud/ios-issues/issues)
* Search the existing issues first, it's likely that your issue was already
  reported.

If your issue appears to be a bug, and hasn't been reported, open a new issue.

Help us to maximize the effort we can spend fixing issues and adding new
features, by not reporting duplicate issues.

[template]: https://raw.github.com/owncloud/client/master/.github/issue_template.md
[mailinglist]: https://mail.kde.org/mailman/listinfo/owncloud
[forum]: http://forum.owncloud.org/
[irc]: http://webchat.freenode.net/?channels=owncloud&uio=d4

## Contributing to Source Code

Thanks for wanting to contribute source code to ownCloud. That's great!

Before we're able to merge your code to ownCloud Desktop Client, you need to sign
our [Contributor Agreement][agreement].

Please read the [Desktop Client Manual][desktopman] and the [Developer
Manuals][devmanual] to get useful info like how to create your first
application or how to test the ownCloud code with phpunit.

[agreement]: http://owncloud.org/about/contributor-agreement/
[devmanual]: http://owncloud.org/dev
[desktopman]: http://doc.owncloud.org/desktop

## Translations
Please submit translations via [Transifex][transifex].

[transifex]: https://www.transifex.com/projects/p/owncloud/
